

Authors
=======

Thank you for supporting RocketCEA.

Development Lead
----------------

* `Charlie Taylor <https://github.com/sonofeft>`_

Patches and Ideas
-----------------

* `stepbot <https://github.com/stepbot>`_
    - MacOS support 

Initial Project Layout
----------------------

RocketCEA Framework was Created by: `PyHatch <http://pyhatch.readthedocs.org/en/latest/>`_ 

(PyHatch Initializes Files And Directory Structures For New Python Projects.)

See PyHatch Docs at: `<http://pyhatch.readthedocs.org/en/latest/>`_
